@@ -35,9 +35,9 @@ class SourceDevice:
         self.log_modified_time = getmtime(log_path)
         self.device_type = None
         self.device_name = None
+        self.ip, self.netmask, self.gateway = self.parse_net_info()
         self.site_name = None
         self.serial_number = None
-        self.net_info = {}
         self.error_list = []
 
 
@@ -59,41 +59,41 @@ class SourceDevice:
 
     @property
     def device_type(self):
-        if self.device_type == None:
-            if re.match(r'^swc1', self.log_filename):
-                device_type = 'core1'
-            if re.match(r'^swc2', self.log_filename):
-                device_type = 'core2'
-            if re.match(r'^sw[0-9][a-z]|^swlp1', self.log_filename):
-                device_type = 'access'
-            if re.match(r'^SPARE', self.log_filename):
-                device_type = 'spare'
+        if re.match(r'^swc1', self.log_filename):
+            device_type = 'core1'
+        elif re.match(r'^swc2', self.log_filename):
+            device_type = 'core2'
+        elif re.match(r'^sw[0-9][a-z]|^swlp1', self.log_filename):
+            device_type = 'access'
+        elif re.match(r'^SPARE', self.log_filename):
+            device_type = 'spare'
+        elif self.log_filename == '':
+            device_type = None
+
         return device_type
 
-    @property
-    def net_info(self):
+    def parse_net_info(self):
         """
         A function to verify the management network information in the startup config.
         Reference information was pulled from the documentation provided the Project Engineers
         and is not guaranteed or intended to cover every project.
         """
-        if self.net_info == None:
-            trigger = 0
-            with open(self.log_file_path) as open_file:
-                for line in open_file.readlines():
-                    if 'interface Vlan31' in line:
-                        trigger = 1
-                        continue
-                    if trigger == 1 and 'ip address ' in line:
-                        net_info = line.strip().split(' ')
-                        self.net_info.update({'ip': net_info[2]})
-                        self.net_info.update({'netmask': net_info[3]})
-                        trigger += 1
-                        continue
-                    if trigger == 2 and 'ip default-gateway' in line:
-                        self.net_info.update({'gateway': line.strip().split(' ')[-1]})
+        trigger = 0
+        with open(self.log_file_path) as open_file:
+            for line in open_file.readlines():
+                if 'interface Vlan31' in line:
+                    trigger = 1
+                    continue
+                if trigger == 1 and 'ip address ' in line:
+                    net_info = line.strip().split(' ')
+                    self.ip = ({'ip': net_info[2]})
+                    self.netmask = ({'netmask': net_info[3]})
+                    trigger += 1
+                    continue
+                if trigger == 2 and 'ip default-gateway' in line:
+                    self.gateway = ({'gateway': line.strip().split(' ')[-1]})
 
-        return self.net_info
+            return (self.ip, self.netmask, self.gateway)
 
     @property
     def startup_config(self):
@@ -135,18 +135,17 @@ class SourceDevice:
         }
 
         error = []
-        net_info = self.net_info
-        if net_info['ip'].rsplit('.', 1)[1] == ip_info[self.device_name] \
-                and net_info['netmask'] == ip_info['netmask'] \
-                and net_info['gateway'].rsplit('.', 1)[1] == ip_info['gw']:
+        if self.ip.rsplit('.', 1)[1] == ip_info[self.device_name] \
+                and self.netmask == ip_info['netmask'] \
+                and self.gateway.rsplit('.', 1)[1] == ip_info['gw']:
             return
-        if net_info['ip'].rsplit('.', 1)[1] != ip_info[self.device_name]:
+        if self.ip.rsplit('.', 1)[1] != ip_info[self.device_name]:
             error.append(f'{self.hostname} ' +
-                        error_codes[1] + '\nCurrent: {}'.format(net_info['ip']))
-        if net_info['netmask'] != ip_info['netmask']:
+                        error_codes[1] + '\nCurrent: {}'.format(self.ip))
+        if self.netmask != ip_info['netmask']:
             error.append(f'{self.hostname} ' +
-                        error_codes[2] + '\nCurrent: {}'.format(net_info['netmask']))
-        if net_info['gateway'].rsplit('.', 1)[1] != ip_info['gw']:
+                        error_codes[2] + '\nCurrent: {}'.format(self.netmask))
+        if self.gateway.rsplit('.', 1)[1] != ip_info['gw']:
             error.append(f'{self.hostname} ' +
                         error_codes[3] + '\nCurrent: {}'.format(net_info['gateway']))
 
